@@ -10,8 +10,10 @@ from urllib2 import urlopen
 from os import path
 import hashlib
 import sys
-
+import viset.util
 import archive
+import os
+
 
 def generate_sha1(filepath):
     sha1 = hashlib.sha1()
@@ -109,3 +111,13 @@ def download_and_extract(url, output_dirname, sha1=None, verbose=True):
     download(url, archive_filename, sha1=sha1, verbose=verbose)
     extract(archive_filename, output_dirname, sha1=sha1, verbose=verbose)
 
+def download_extract_cleanup(url, output_dirname, sha1=None, verbose=True):
+    download_and_extract(url, output_dirname, sha1, verbose)
+    os.remove(path.join(output_dirname, path.basename(url)))
+
+def cache_and_extract(url, output_dirname, sha1=None, verbose=True):
+    if not viset.util.isfile(path.join(output_dirname, path.basename(url))):
+        download_and_extract(url, output_dirname, sha1, verbose)
+        
+
+    
